@@ -22,8 +22,8 @@
 #include <stdint.h>
 #include <string.h>
 
-#include "lv2/lv2plug.in/ns/ext/atom/atom.h"
-#include "lv2/lv2plug.in/ns/ext/urid/urid.h"
+#include "lv2/atom/atom.h"
+#include "lv2/urid/urid.h"
 
 class AudioEffect;
 
@@ -149,4 +149,3 @@ AudioEffectX* lvz_new_audioeffectx();
 }
 
 #endif // LVZ_AUDIOEFFECTX_H
-
