@@ -18,7 +18,7 @@
 
 #include "mdaDX10.h"
 
-#include "lv2/lv2plug.in/ns/ext/atom/util.h"
+#include "lv2/atom/util.h"
 
 #include <stdio.h>
 #include <stdlib.h> //rand()
